@@ -1,7 +1,7 @@
 #' @name csv_to_parquet
-#' @title Convert a csv file to parquet format
+#' @title Convert a csv or a txt file to parquet format
 #'
-#' @description This function allows to convert a csv file to parquet format. \cr
+#' @description This function allows to convert a csv or a txt file to parquet format. \cr
 #'
 #' Two conversions possibilities are offered :
 #'
@@ -12,17 +12,18 @@
 #'
 #' }
 #'
-#' @param filename_in_zip name of the csv file in the zip. Required if several csv are included in the zip.
+#' @param filename_in_zip name of the csv/txt file in the zip. Required if several csv/txt are included in the zip.
 #' @param url_to_csv DEPRECATED use path_to_file instead
 #' @param csv_as_a_zip DEPRECATED
 #' @inheritParams table_to_parquet
+#' @param read_delim_args list of arguments for `read_delim`.
 #' @param ... additional format-specific arguments, see \href{https://arrow.apache.org/docs/r/reference/write_parquet.html}{arrow::write_parquet()}
 #'  and \href{https://arrow.apache.org/docs/r/reference/write_dataset.html}{arrow::write_dataset()} for more informations.
 #'
 #' @note Be careful, if the zip size exceeds 4 GB, the function may truncate
 #' the data (because unzip() won't work reliably in this case -
 #' see \href{https://rdrr.io/r/utils/unzip.html}{here}).
-#' In this case, it's advised to unzip your csv file by hand
+#' In this case, it's advised to unzip your csv/txt file by hand
 #' (for example with \href{https://www.7-zip.org/}{7-Zip})
 #' then use the function with the argument `path_to_file`.
 #'
@@ -39,6 +40,13 @@
 #'   path_to_parquet = tempfile(fileext=".parquet")
 #' )
 #'
+#' # Conversion from a local txt file to a single parquet file :
+#'
+#' csv_to_parquet(
+#'   path_to_file = parquetize_example("region_2022.txt"),
+#'   path_to_parquet = tempfile(fileext=".parquet")
+#' )
+#'
 #' # Conversion from a local csv file to a single parquet file and select only
 #' # few columns :
 #'
@@ -57,14 +65,33 @@
 #'   partitioning =  c("REG")
 #' )
 #'
-#' # Conversion from a URL and a zipped file :
+#' # Conversion from a URL and a zipped file (csv) :
 #'
 #' csv_to_parquet(
 #'   path_to_file = "https://www.nomisweb.co.uk/output/census/2021/census2021-ts007.zip",
 #'   filename_in_zip = "census2021-ts007-ctry.csv",
 #'   path_to_parquet = tempfile(fileext = ".parquet")
 #' )
-
+#'
+#' # Conversion from a URL and a zipped file (txt) :
+#'
+#' csv_to_parquet(
+#'   path_to_file = "https://sourceforge.net/projects/irisdss/files/latest/download",
+#'   filename_in_zip = "IRIS TEST data.txt",
+#'   path_to_parquet = tempfile(fileext=".parquet")
+#' )
+#'
+#' \dontrun{
+#' # Conversion from a URL and a csv file with "gzip" compression :
+#'
+#' csv_to_parquet(
+#'   path_to_file =
+#'   "https://github.com/sidsriv/Introduction-to-Data-Science-in-python/raw/master/census.csv",
+#'   path_to_parquet = tempfile(fileext = ".parquet"),
+#'   compression = "gzip",
+#'   compression_level = 5
+#' )
+#' }
 csv_to_parquet <- function(
     path_to_file,
     url_to_csv = lifecycle::deprecated(),
@@ -76,6 +103,7 @@ csv_to_parquet <- function(
     compression_level = NULL,
     partition = "no",
     encoding = "UTF-8",
+    read_delim_args = list(),
     ...
 ) {
   if (!missing(url_to_csv)) {
@@ -120,12 +148,15 @@ csv_to_parquet <- function(
   Sys.sleep(0.01)
   cli_progress_message("Reading data...")
 
-  csv_output <- read_delim(
-    file = input_file,
-    locale = locale(encoding = encoding),
-    lazy = TRUE,
-    show_col_types = FALSE,
-    col_select = if (identical(columns,"all")) everything() else all_of(columns)
+  csv_output <- inject(
+    read_delim(
+      file = input_file,
+      locale = locale(encoding = encoding),
+      lazy = TRUE,
+      show_col_types = FALSE,
+      col_select = if (identical(columns,"all")) everything() else all_of(columns),
+      !!!read_delim_args
+    )
   )
 
   dataset <- write_parquet_at_once(
